@@ -36,7 +36,7 @@ class TempoPointToBeatLengthInSeconds(core_converters.abc.Converter):
     >>> tempo_point_converter = core_converters.TempoPointToBeatLengthInSeconds()
     """
 
-    TempoPoint = typing.Union[core_parameters.abc.TempoPoint, core_constants.Real]
+    TempoPoint = core_parameters.abc.TempoPoint | core_constants.Real
 
     @staticmethod
     def _beats_per_minute_to_seconds_per_beat(
@@ -145,7 +145,7 @@ class TempoConverter(core_converters.abc.EventConverter):
         """Convert bpm / TempoPoint based env to beat-length-in-seconds env."""
 
         level_list: list[float] = []
-        for tempo_point in tempo_envelope.value_tuple:
+        for tempo_point in tempo_envelope.parameter_tuple:
             beat_length_in_seconds = (
                 TempoConverter._tempo_point_to_beat_length_in_seconds(tempo_point)
             )
@@ -169,7 +169,7 @@ class TempoConverter(core_converters.abc.EventConverter):
     def _convert_simple_event(
         self,
         simple_event: core_events.SimpleEvent,
-        absolute_entry_delay: typing.Union[core_parameters.abc.Duration, float, int],
+        absolute_entry_delay: core_parameters.abc.Duration | float | int,
         depth: int = 0,
     ) -> tuple[typing.Any, ...]:
         simple_event.duration = (
@@ -182,7 +182,7 @@ class TempoConverter(core_converters.abc.EventConverter):
     def _convert_event(
         self,
         event_to_convert: core_events.abc.Event,
-        absolute_entry_delay: typing.Union[core_parameters.abc.Duration, float, int],
+        absolute_entry_delay: core_parameters.abc.Duration | float | int,
         depth: int = 0,
     ) -> core_events.abc.ComplexEvent[core_events.abc.Event]:
         if self._apply_converter_on_events_tempo_envelope:
@@ -246,7 +246,7 @@ class EventToMetrizedEvent(core_converters.abc.SymmetricalEventConverter):
     def _convert_simple_event(
         self,
         event_to_convert: core_events.SimpleEvent,
-        absolute_entry_delay: typing.Union[core_parameters.abc.Duration, float, int],
+        absolute_entry_delay: core_parameters.abc.Duration | float | int,
         depth: int = 0,
     ) -> core_events.SimpleEvent:
         return event_to_convert
@@ -254,7 +254,7 @@ class EventToMetrizedEvent(core_converters.abc.SymmetricalEventConverter):
     def _convert_event(
         self,
         event_to_convert: core_events.abc.Event,
-        absolute_entry_delay: typing.Union[core_parameters.abc.Duration, float, int],
+        absolute_entry_delay: core_parameters.abc.Duration | float | int,
         depth: int = 0,
     ) -> core_events.abc.ComplexEvent[core_events.abc.Event]:
         if (self._skip_level_count is None or self._skip_level_count < depth) and (
@@ -264,7 +264,7 @@ class EventToMetrizedEvent(core_converters.abc.SymmetricalEventConverter):
             event_to_convert = tempo_converter.convert(event_to_convert)
             event_to_convert.reset_tempo_envelope()
         else:
-            # XXX: Ensure we return copied event!
+            # Ensure we return copied event!
             event_to_convert = event_to_convert.destructive_copy()
         return super()._convert_event(event_to_convert, absolute_entry_delay, depth)
 
