@@ -75,6 +75,15 @@ class Envelope(
     `expenvelope <https://git.sr.ht/~marcevanstein/expenvelope>`_
     python package and is made to fit better into the `mutwo` ecosystem.
 
+    **Hint:**
+
+    When comparing two envelopes (e.g. `env0 == env1`) `mutwo` will only return
+    `True` in case all control points (= simple events inside the envelope) are
+    equal between both envelopes. So `mutwo` won't make the much more
+    complicated test to check if two envelopes have the same shape (= the same
+    value at each `env0.value_at(x) == env1.value_at(x)` for each possible
+    `x`). Such a test is not implemented yet.
+
     **Example:**
 
     >>> from mutwo import core_events
@@ -89,13 +98,11 @@ class Envelope(
     CompletePoint = tuple[
         core_constants.DurationType, core_constants.ParameterType, CurveShape  # type: ignore
     ]
-    Point = typing.Union[CompletePoint, IncompletePoint]
+    Point = CompletePoint | IncompletePoint
 
     def __init__(
         self,
-        event_iterable_or_point_sequence: typing.Union[
-            typing.Iterable[T], typing.Sequence[Point]
-        ],
+        event_iterable_or_point_sequence: typing.Iterable[T] | typing.Sequence[Point],
         tempo_envelope: typing.Optional[core_events.TempoEnvelope] = None,
         event_to_parameter: typing.Callable[
             [core_events.abc.Event], core_constants.ParameterType
@@ -177,18 +184,14 @@ class Envelope(
     def __setitem__(
         self,
         index_or_slice: slice,
-        event_or_sequence: typing.Union[
-            typing.Iterable[T], typing.Iterable[Envelope.Point]
-        ],
+        event_or_sequence: typing.Iterable[T] | typing.Iterable[Envelope.Point],
     ):
         ...
 
     def __setitem__(
         self,
-        index_or_slice: typing.Union[int, slice],
-        event_or_sequence: typing.Union[
-            T, typing.Iterable[T], typing.Iterable[Envelope.Point]
-        ],
+        index_or_slice: int | slice,
+        event_or_sequence: T | typing.Iterable[T] | typing.Iterable[Envelope.Point],
     ):
         if isinstance(index_or_slice, slice) and isinstance(
             event_or_sequence, typing.Iterable
@@ -204,9 +207,9 @@ class Envelope(
 
     @staticmethod
     def _point_sequence_to_corrected_point_list(
-        point_or_invalid_type_sequence: typing.Sequence[typing.Union[Point, typing.Any]]
-    ) -> list[typing.Union[Envelope.CompletePoint, None]]:
-        corrected_point_list: list[typing.Union[Envelope.CompletePoint, None]] = []
+        point_or_invalid_type_sequence: typing.Sequence[Point | typing.Any],
+    ) -> list[Envelope.CompletePoint | None]:
+        corrected_point_list: list[Envelope.CompletePoint | None] = []
         for point in point_or_invalid_type_sequence:
             point_count = len(point)
             if point_count == 2:
@@ -228,9 +231,7 @@ class Envelope(
 
     def _point_sequence_to_event_list(
         self,
-        point_or_invalid_type_sequence: typing.Sequence[
-            typing.Union[Point, typing.Any]
-        ],
+        point_or_invalid_type_sequence: typing.Sequence[Point | typing.Any],
     ) -> list[core_events.abc.Event]:
         corrected_point_list = Envelope._point_sequence_to_corrected_point_list(
             point_or_invalid_type_sequence
@@ -254,9 +255,7 @@ class Envelope(
 
     def _event_iterable_or_point_sequence_to_event_iterable(
         self,
-        event_iterable_or_point_sequence: typing.Union[
-            typing.Iterable[T], typing.Sequence[Point]
-        ],
+        event_iterable_or_point_sequence: typing.Iterable[T] | typing.Sequence[Point],
     ) -> typing.Iterable[core_events.abc.Event]:
         item_type_list = [
             isinstance(event_or_point, core_events.abc.Event)
@@ -308,7 +307,7 @@ class Envelope(
     # ###################################################################### #
 
     def value_at(
-        self, absolute_time: typing.Union[core_parameters.abc.Duration, typing.Any]
+        self, absolute_time: core_parameters.abc.Duration | typing.Any
     ) -> Value:
         absolute_time_in_floats = core_events.configurations.UNKNOWN_OBJECT_TO_DURATION(
             absolute_time
@@ -362,23 +361,22 @@ class Envelope(
         )
 
     def parameter_at(
-        self, absolute_time: typing.Union[core_parameters.abc.Duration, typing.Any]
+        self, absolute_time: core_parameters.abc.Duration | typing.Any
     ) -> core_constants.ParameterType:
         return self.value_to_parameter(self.value_at(absolute_time))
 
     @core_utilities.add_copy_option
     def sample_at(
         self,
-        absolute_time: typing.Union[core_parameters.abc.Duration, typing.Any],
-        append_duration: typing.Union[
-            core_parameters.abc.Duration, typing.Any
-        ] = core_parameters.DirectDuration(0),
+        absolute_time: core_parameters.abc.Duration | typing.Any,
+        append_duration: core_parameters.abc.Duration
+        | typing.Any = core_parameters.DirectDuration(0),
     ) -> Envelope:
         """Discretize envelope at given time
 
         :param absolute_time: Position in time where the envelope should
             define a new event.
-        :type absolute_time: typing.Union[core_parameters.abc.Duration, typing.Any]
+        :type absolute_time: core_parameters.abc.Duration | typing.Any
         :param append_duration: In case we add a new control point after any
             already defined point, the duration of this control point will be
             equal to "append_duration". Default to core_parameters.DirectDuration(0)
@@ -464,12 +462,8 @@ class Envelope(
 
     def get_average_value(
         self,
-        start: typing.Optional[
-            typing.Union[core_parameters.abc.Duration, typing.Any]
-        ] = None,
-        end: typing.Optional[
-            typing.Union[core_parameters.abc.Duration, typing.Any]
-        ] = None,
+        start: typing.Optional[core_parameters.abc.Duration | typing.Any] = None,
+        end: typing.Optional[core_parameters.abc.Duration | typing.Any] = None,
     ) -> Value:
         if start is None:
             start = core_parameters.DirectDuration(0)
@@ -497,8 +491,8 @@ class Envelope(
     @core_utilities.add_copy_option
     def cut_out(
         self,
-        start: typing.Union[core_parameters.abc.Duration, typing.Any],
-        end: typing.Union[core_parameters.abc.Duration, typing.Any],
+        start: core_parameters.abc.Duration | typing.Any,
+        end: core_parameters.abc.Duration | typing.Any,
     ) -> Envelope[T]:
         start, end = (
             core_events.configurations.UNKNOWN_OBJECT_TO_DURATION(unknown_object)
@@ -528,8 +522,8 @@ class Envelope(
     @core_utilities.add_copy_option
     def cut_off(
         self,
-        start: typing.Union[core_parameters.abc.Duration, typing.Any],
-        end: typing.Union[core_parameters.abc.Duration, typing.Any],
+        start: core_parameters.abc.Duration | typing.Any,
+        end: core_parameters.abc.Duration | typing.Any,
     ) -> Envelope[T]:
         start, end = (
             core_events.configurations.UNKNOWN_OBJECT_TO_DURATION(unknown_object)
@@ -537,7 +531,7 @@ class Envelope(
         )
 
         if (cut_off_duration := end - start) > 0:
-            # XXX: It is sufficient to find the first control point
+            # It is sufficient to find the first control point
             # by simply using "parameter_at" instead of "sample_at":
             # We don't need an accurate curve_shape or duration,
             # because this point only exists in an infinitely short
@@ -554,6 +548,27 @@ class Envelope(
 
         return self
 
+    @core_utilities.add_copy_option
+    def extend_until(
+        self,
+        duration: core_parameters.abc.Duration,
+        duration_to_white_space: typing.Optional[
+            typing.Callable[[core_parameters.abc.Duration], core_events.abc.Event]
+        ] = None,
+        prolong_simple_event: bool = True,
+    ) -> Envelope[T]:
+        self_duration = self.duration
+        super().extend_until(
+            duration,
+            duration_to_white_space=duration_to_white_space
+            or (
+                lambda duration: self._make_event(
+                    duration, self.parameter_at(self_duration), 0
+                )
+            ),
+            prolong_simple_event=prolong_simple_event,
+        )
+
 
 class RelativeEnvelope(Envelope, typing.Generic[T]):
     __parent_doc_string = Envelope.__doc__.split("\n")[2:]  # type: ignore
@@ -590,7 +605,7 @@ class RelativeEnvelope(Envelope, typing.Generic[T]):
 
     def resolve(
         self,
-        duration: typing.Union[core_parameters.abc.Duration, typing.Any],
+        duration: core_parameters.abc.Duration | typing.Any,
         base_parameter: core_constants.ParameterType,
         resolve_envelope_class: type[Envelope] = Envelope,
     ) -> Envelope:
@@ -616,7 +631,7 @@ class RelativeEnvelope(Envelope, typing.Generic[T]):
         return resolve_envelope_class(point_list)
 
 
-TempoPoint = typing.Union[core_parameters.abc.TempoPoint, core_constants.Real]
+TempoPoint = core_parameters.abc.TempoPoint | core_constants.Real
 
 
 class TempoEnvelope(Envelope):
@@ -683,7 +698,7 @@ class TempoEnvelope(Envelope):
             return core_parameters.DirectTempoPoint(value)
 
         def default_parameter_to_value(parameter: TempoPoint) -> float:
-            # XXX: Here we specify, that we allow either core_parameters.abc.TempoPoint
+            # Here we specify, that we allow either core_parameters.abc.TempoPoint
             # or float/number objects.
             # So in case we have a core_parameters.abc.TempoPoint 'getattr' is
             # successful, if not it will return 'parameter', because it
@@ -712,13 +727,13 @@ class TempoEnvelope(Envelope):
         )
 
     def __eq__(self, other: typing.Any):
-        # XXX: TempoEnvelope can't use the default '__eq__' method inherited
+        # TempoEnvelope can't use the default '__eq__' method inherited
         # from list, because this would create endless recursion
         # (because every event has a TempoEnvelope, so Python would forever
         #  compare the TempoEnvelopes of TempoEnvelopes).
         try:
             return (
-                # XXX: Prefer lazy evaluation for better performance
+                # Prefer lazy evaluation for better performance
                 # (use 'and' instead of 'all').
                 self.absolute_time_tuple == other.absolute_time_tuple
                 and self.curve_shape_tuple == other.curve_shape_tuple
